<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 21/04/20
 * Time: 11.57
 */

namespace FiloBlu\Rma\Handlers;
use Magento\Rma\Api\RmaRepositoryInterface;
use Magento\Sales\Model\Order;
use Psr\Log\LoggerInterface;

class CancelChangeSizeOrderHandler
{
    /**
     * @var RmaRepositoryInterface
     */
    private $rmaRepository;
    /**
     * @var Order
     */
    private $order;
    /**
     * @var LoggerInterface
     */
    private $logger;


    /**
     * CancelChangeSizeOrderHandler constructor.
     * @param RmaRepositoryInterface $rmaRepository
     * @param Order $order
     * @param LoggerInterface $logger
     */
    public function __construct(
        RmaRepositoryInterface $rmaRepository,
        Order $order,
        LoggerInterface $logger){
        $this->rmaRepository = $rmaRepository;
        $this->order = $order;
        $this->logger = $logger;
    }


    /**
     * @param \Magento\Rma\Model\Rma $subject
     * @param $result
     * @return mixed
     */
    public function cancelChangeSizeOrder(\Magento\Rma\Model\Rma $subject, $result){
        try{
            if($result->getStatus() == 'closed'){
                $rma = $this->rmaRepository->get($subject->getEntityId());
                foreach ($rma->getItems() as $rmaItem){
                    $attributes = $rmaItem->getExtensionAttributes();
                    if($attributes === null){
                        continue;
                    }
                    $changeSizeOrderIncrementId = $rmaItem->getExtensionAttributes()->getChangeSizeOrderIncrementId();

                    if($changeSizeOrderIncrementId){
                        $changeSizeOrder = $this->order->loadByIncrementId($changeSizeOrderIncrementId);
                        $changeSizeOrder->setStatus('canceled')->setState('canceled');
                        $changeSizeOrder->save();
                    }
                }

            }
            return $result;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return $result;
        }catch (\Throwable $t){
            $this->logger->critical($t->getMessage());
            return $result;
        }
    }

}